.BG
.FN poly.fit
.TL
Polychotomous Regression and Multiple Classification
.SH DESCRIPTION
poly.fit -  polychotomous regression and multiple classification
using linear splines and selected tensor products.
.CS
poly.fit(data, cov, weight, penalty, maxdim, exclude, 
        include, additive=F, linear, delete = 2, fit,  silent = T, 
	normweight = T, tdata, tcov, tweight, cv, select, loss, 
	delete, seed)
.RA
.AG data
vector of classes. 
Data should ranges over consecutive integers with 0 or 1 as the minimum value.
.AG cov
covariates: matrix with as many rows as the length of data. 
.AG weight
vector of case-weights. 
Should have the same length as data. May be omitted if all weights are one.
.AG penalty
the parameter to be used in the AIC criterion if the
model selection is carried out by AIC.  The program chooses
the number of knots that minimizes -2 * loglikelihood + penalty * (dimension).
The default is to use penalty = log(sample size) as in BIC. If the model
selection is carried out by cross-validation or using a test set, the
program uses the number of knots that minimizes
loss + penalty * dimension * (loss for smallest model). In this case
the default of penalty is 0.
is ignored.
.AG maxdim
maximum dimension (default is 6 * length(class)^0.2).
.AG exclude
combinations to be excluded - this should be a matrix with 2
columns - if for example exclude(1,1)=2 and exclude(1,2)=3 no
interaction between covariate 2 and 3 is included. 
.AG include
those combinations that can be included. Should have the same format
as exclude. Only one of the exclude and include can be specified.
.AG additive
should an additive model be fitted?
.AG linear
vector indicating for which of the variables no knots should
be entered. For example, if linear=c(2,3) no knots for covariate
2 or 3 are entered. 
.AG delete
should complete basis functions be deleted at once (2), should
only individual dimensions be deleted (1) or should only the addition
stage of the model selection be carried out (0)?
.AG fit
object created by poly.fit. If a fit is specified, poly.fit adds
basis functions starting with those in the specified fit.
.AG silent
suppresses the printing of diagnostic output about basis functions added
or deleted, Rao-statistics, Wald-statistics, log-likelihoods and loss
functions.
.AG normweight
should the weights be normalized so that they average to one? This option
has only an effect if the model is selected using AIC.
.AG tdata
.AG tcov
.AG tweight
test set. Should satisfy the same requirements as class, cov and weight. If
all test set weights are one, tweight can be omitted. If tdata and tcov are
specified, the model selection is carried out using this test set, irrespective
of the input for penalty or cv.
.AG cv
in how many subsets should the data be divided for cross-validation? If cv is
specified and tdata is omitted, the model selection is carried out by
cross-validation irrespective of the input for penalty.
.AG select
if a test set is provided, or if the model is selected using cross validation,
should the model be select that minimizes (misclassification) loss (0), that
maximizes test set log-likelihood (1) or that minimizes test set
squared error loss (2)?
.AG loss
a rectangular matrix specifying the loss function, whose
size is the number of
classes times number of actions.
Used for cross-validation and test set model
selection. If loss is a matrix, loss[i,j] contains the loss for
assigning action j  to an object whose true class is i.
The default is 1 minus the identity matrix.
.AG seed
optional
seed for the random number generator that determines the sequence of the
cases for cross-validation. If the seed has length 12 or more,
the first twelve elements are assumed to be .Random.seed, otherwise
the function set.seed is used. 
If seed is 0 or rep(0,12), it is assumed that the user
has already provided a (random) ordering.
If seed is not provided, while a fit with
an element fit$seed is provided, .Random.seed is set to fit$seed. Otherwise
the present value of .Radom.seed is used.
.RT
The output is organized to serve as input for `poly.plot',
`poly.beta',
`poly.summary', `ppoly', `cpoly' and `rpoly'.
The function returns a list with the following members:
.RC call
the command that was executed.
.RC ncov
number of covariates
.RC ndim
number of dimensions of the fitted model.
.RC nclass
number of classes.
.RC nbas
number of basis functions.
.RC naction
number of possible actions that are considered.
.RC fcts
matrix of size nbas x (nclass +4). each row is a basis function.
First element: first covariate involved (NA=constant);
.br
second element: which knot (NA means: constant or linear);
.br
third element: second covariate involved (NA means: this is a function
of one variable);
.br
fourth element: knot involved (if the third element is NA, of no relevance);
.br
fifth, sixth,...  element: beta for class one, two, ...
.RC knots
a matrix of size ncov x ?
one row for each dimension. Covariate i has row i.
first element - number of knots in this dimension
other elements - the knots, appended with NAs to make it a matrix
.RC cv
in how many sets was the data divided for cross-validation.
Only provided if method=2.
.RC loss
the loss matrix used in cross-validation and test set.
Only provided if method=1 or method=2.
.RC penalty
the parameter used in the AIC criterion. Only provided if method=0.
.RC method
0=AIC, 1=test set, 2=cross-validation.
.RC ranges
column i gives the range of the i-th covariate.
.RC logl
matrix with eight or eleven columns. Summarizes fits.
Column one indicates the dimension, column
column two the AIC or loss value, whichever was
used during the model selection
appropriate, column three four and five give the training set log-likelihood,
(misclassification) loss and squared error loss, columns six to
eight give the same information for the test set, column nine (or column
six if method=0 or method=2) indicates whether the
model was fitted during the addition stage (1) or during the deletion stage (0),
column ten and eleven (or seven and eight) the minimum and maximum
penalty parameter for which AIC would have selected this model.
.RC sample
sample size.
.RC tsample
the sample size of the test set. Only prvided if method=1.
.RC wgtsum
sum of the case weights.
.RC covnames
names of the covariates.
.RC classnames
(numerical) names of the classes.
.RC cv.aic
the penalty value that was determined optimal by
by cross validation. Only provided if method=2.
.RC cv.tab
table with three columns. Column one and two indicate the penalty parameter
range for which the cv-loss in column three would be realized.
.RC seed
the random seed that was used to determine the order
of the cases for cross-validation. Only provided if
method=2.
.RC delete
were complete basis functions deleted at once (2), were
only individual dimensions deleted (1) or was only the addition
stage of the model selection carried out (0)?
.RC beta
moments of basisfunctions. Needed for poly.beta.
.RC select
if a test set is provided, or if the model is selected using cross validation,
was the model selected that minimized (misclassification) loss (0), that
maximized test set log-likelihood (1) or that minimized test set
squared error loss (2)?
.RC anova
matrix with three columns. The first two elements in a line
indicate the subspace to which the line refers. The third element indicates
the percentage of variance explained by that subspace.
.RC twgtsum
sum of the test set case weights (only if method = 1).
.SH REFERENCE
Bose, S., Kooperberg, C. and Stone, C. J. (1997),
Polychotomous Regression.
.ul
Journal of the American Statistical Association
.SA
`poly.beta', `poly.plot', `poly.summary', `ppoly', `cpoly' and `rpoly'.
.WR
